#!/bin/bash
# run qmake for all pro files in project tree
PROFILES=`find . -name "*.pro"`
for i in $PROFILES; do
    pushd . > /dev/null
    cd `dirname $i`
    qmake
    popd > /dev/null
done
